@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -35,21 +35,43 @@ PyMethodDef xcsoar_methods[] = {
   {nullptr, nullptr, 0, nullptr}
 };
 
-PyMODINIT_FUNC
-__attribute__ ((visibility("default")))
-initxcsoar() {
-  PyObject* m;
+#if PY_MAJOR_VERSION >= 3
+  #define MOD_INIT(name) \
+          PyMODINIT_FUNC \
+          PyInit_##name()
+  #define MOD_DEF(ob, name, doc, methods) \
+          static struct PyModuleDef moduledef = { \
+            PyModuleDef_HEAD_INIT, name, doc, -1, methods, }; \
+          ob = PyModule_Create(&moduledef);
+  #define MOD_ERROR_VAL NULL
+  #define MOD_SUCCESS_VAL(val) val
 
-  m = Py_InitModule3("xcsoar", xcsoar_methods, "XCSoar Tools");
+#else
+  #define MOD_INIT(name) \
+          PyMODINIT_FUNC \
+          __attribute__ ((visibility("default"))) \
+          init##name()
+  #define MOD_DEF(ob, name, doc, methods) \
+          ob = Py_InitModule3(name, methods, doc);
+  #define MOD_ERROR_VAL
+  #define MOD_SUCCESS_VAL(val)
+#endif
+
+MOD_INIT(xcsoar) {
+  PyObject *m;
+
+  MOD_DEF(m, "xcsoar", "XCSoar Tools", xcsoar_methods)
 
   if (m == nullptr)
-    return;
+    return MOD_ERROR_VAL;
 
   PyDateTime_IMPORT;
 
   if (!Flight_init(m))
-    return;
+    return MOD_ERROR_VAL;
 
   if (!Airspaces_init(m))
-    return;
+    return MOD_ERROR_VAL;
+
+  return MOD_SUCCESS_VAL(m);
 }
