@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -220,7 +220,7 @@ constexpr
 static inline bool
 IsEmbedded()
 {
-  return IsAndroid() || IsWindowsCE() || IsKobo();
+  return IsAndroid() || IsWindowsCE() || IsKobo() || IsIOS();
 }
 
 /**
@@ -271,24 +271,36 @@ HasPointer()
  * Does this device have a touch screen?  This is useful to know for
  * sizing controls, as a touch screen may require bigger areas.
  */
+#ifdef USE_LIBINPUT
+gcc_pure
+bool
+HasTouchScreen();
+#else
 constexpr
 static inline bool
 HasTouchScreen()
 {
-  return IsAndroid() || (IsWindowsCE() && !IsAltair()) || IsKobo();
+  return IsAndroid() || (IsWindowsCE() && !IsAltair()) || IsKobo() || IsIOS();
 }
+#endif
 
 /**
  * Does this device have a keyboard device?
  * @return True if a keyboard is assumed for the hardware
  * that XCSoar is running on, False if the hardware has no keyboard
  */
+#ifdef USE_LIBINPUT
+gcc_pure
+bool
+HasKeyboard();
+#else
 constexpr
 static inline bool
 HasKeyboard()
 {
   return !IsEmbedded();
 }
+#endif
 
 /**
  * Does this device have a cursor keys?  These may be used to navigate
@@ -307,7 +319,7 @@ HasCursorKeys()
 #ifdef ANDROID
   return has_cursor_keys;
 #else
-  return !IsKobo();
+  return !IsKobo() && !IsIOS();
 #endif
 }
 
