@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,6 +26,7 @@ Copyright_License {
 #include "Units/Units.hpp"
 #include "NMEA/Info.hpp"
 #include "NMEA/Derived.hpp"
+#include "Util/StringAPI.hpp"
 
 #include <stdio.h>
 
@@ -169,7 +170,7 @@ void VegaVoiceMessage::SendMessage() {
 
 
   /*
-  if (_tcscmp(messageText, last_messageText)==0) {
+  if (StringIsEqual(messageText, last_messageText)) {
     // no change, no need to send
     return;
   }
