@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -62,9 +62,6 @@ CalculationThread::Tick()
   const ScopeLockCPU cpu;
 #endif
 
-  const Validity previous_warning =
-    glide_computer.Calculated().airspace_warnings.latest;
-
   bool gps_updated;
 
   // update and transfer master info to glide computer
@@ -114,17 +111,6 @@ CalculationThread::Tick()
   if (do_idle) {
     // do slow calculations last, to minimise latency
     glide_computer.ProcessIdle();
-
-    if (glide_computer.Calculated().airspace_warnings.latest != previous_warning) {
-      /* there's a new airspace warning */
-
-      {
-        ScopeLock protect(device_blackboard->mutex);
-        device_blackboard->ReadBlackboard(glide_computer.Calculated());
-      }
-
-      TriggerAirspaceWarning();
-    }
   }
 }
 
