@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -37,6 +37,7 @@ Copyright_License {
 #include "Plane/Plane.hpp"
 #include "Wind/Settings.hpp"
 #include "Audio/VegaVoiceSettings.hpp"
+#include "WaveSettings.hpp"
 
 #include <type_traits>
 
@@ -173,6 +174,8 @@ struct ComputerSettings {
 
   CirclingSettings circling;
 
+  WaveSettings wave;
+
   AverageEffTime average_eff_time;
 
   /** Update system time from GPS time */
