@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -56,6 +56,10 @@ public:
                const Airspaces &airspace_database,
                const ProtectedAirspaceWarningManager *warnings);
 
+  const ProtectedTaskManager &GetProtectedTaskManager() const {
+    return task;
+  }
+
   const ProtectedRoutePlanner &GetProtectedRoutePlanner() const {
     return route.GetProtectedRoutePlanner();
   }
