@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -145,7 +145,7 @@ CirclingWind::CalcWind()
   assert(!samples.empty());
 
   // reject if average time step greater than 2.0 seconds
-  if ((samples.last().time - samples[0].time) / (samples.size() - 1) > fixed(2))
+  if ((samples.back().time - samples[0].time) / (samples.size() - 1) > fixed(2))
     return Result(0);
 
   // find average
