@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -28,6 +28,6 @@ WindSettings::SetDefaults()
 {
   circling_wind = true;
   zig_zag_wind = true;
-  use_external_wind = true;
+  external_wind = true;
   manual_wind_available.Clear();
 }
