@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -30,13 +30,14 @@ uint16_t
 FLARM::CalculateCRC(const FrameHeader &header,
                     const void *data, size_t length)
 {
-  assert((data != NULL && length > 0) || (data == NULL && length == 0));
+  assert((data != nullptr && length > 0) ||
+         (data == nullptr && length == 0));
 
   uint16_t crc = 0x00;
 
   crc = UpdateCRC16CCITT((const uint8_t *)&header, 6, crc);
 
-  if (length == 0 || data == NULL)
+  if (length == 0 || data == nullptr)
     return crc;
 
   crc = UpdateCRC16CCITT((const uint8_t *)data, length, crc);
