@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -156,7 +156,7 @@ protected:
   fixed ApplyShiftedHandicap(const fixed unhandicapped_score) const {
     assert(handicap != 0);
 
-    return 200 * unhandicapped_score / (100 + handicap);
+    return 400 * unhandicapped_score / (3 * handicap + 100);
   }
 };
 
