@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -34,7 +34,7 @@ public:
 
 protected:
   /* virtual methods from class AbstractContest */
-  virtual ContestResult CalculateResult() const override;
+  ContestResult CalculateResult() const override;
 };
 
 #endif
