@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -54,24 +54,22 @@ public:
                    const AGeoPoint &origin,
                    const AGeoPoint &destination);
 
-  virtual void Reset() override;
+  void Reset() override;
 
   unsigned AirspaceSize() const;
 
 protected:
 
-  virtual void OnSolve(const AGeoPoint &origin,
-                       const AGeoPoint &destination) override;
+  void OnSolve(const AGeoPoint &origin, const AGeoPoint &destination) override;
 
-  virtual bool IsTrivial() const override {
+  bool IsTrivial() const override {
     return m_airspaces.IsEmpty() && RoutePlanner::IsTrivial();
   }
 
 private:
-  virtual bool CheckClearance(const RouteLink &e,
-                              RoutePoint &inp) const override;
-  virtual void AddNearby(const RouteLink &e) override;
-  virtual bool CheckSecondary(const RouteLink &e) override;
+  bool CheckClearance(const RouteLink &e, RoutePoint &inp) const override;
+  void AddNearby(const RouteLink &e) override;
+  bool CheckSecondary(const RouteLink &e) override;
 
   void AddNearbyAirspace(const RouteAirspaceIntersection &inx,
                          const RouteLink &e);
