@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -29,7 +29,7 @@
 
 #include <list>
 
-class TaskProjection;
+class FlatProjection;
 struct GeoPoint;
 struct RouteLink;
 struct AFlatGeoPoint;
@@ -105,7 +105,7 @@ public:
                            RoughAltitude &arrival_height) const;
 
   void AcceptInRange(const FlatBoundingBox &bb,
-                     const TaskProjection &task_proj,
+                     const FlatProjection &projection,
                      TriangleFanVisitor &visitor) const;
 
   void UpdateTerrainBase(const FlatGeoPoint &origin, ReachFanParms &parms);
