@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 #ifndef REACHFAN_HPP
 #define REACHFAN_HPP
 
-#include "Geo/Flat/TaskProjection.hpp"
+#include "Geo/Flat/FlatProjection.hpp"
 #include "FlatTriangleFanTree.hpp"
 #include "Rough/RoughAltitude.hpp"
 
@@ -34,7 +34,7 @@ struct ReachResult;
 
 class ReachFan
 {
-  TaskProjection task_proj;
+  FlatProjection projection;
   FlatTriangleFanTree root;
   RoughAltitude terrain_base;
 
