@@ -2,7 +2,7 @@
   Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -59,7 +59,8 @@ public:
    * @param previous Previous task point (origin of inbound leg)
    * @param next Following task point (destination of outbound leg)
    */
-  virtual void SetLegs(const GeoPoint *previous, const GeoPoint *next) {}
+  virtual void SetLegs(gcc_unused const GeoPoint *previous,
+                       gcc_unused const GeoPoint *next) {}
 
   /**
    * Test whether an OZ is equivalent to this one
