@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 #include "Task/AbstractTask.hpp"
 #include "SmartTaskAdvance.hpp"
 #include "Util/DereferenceIterator.hpp"
-#include "Util/StaticString.hpp"
+#include "Util/StaticString.hxx"
 
 #include <assert.h>
 #include <vector>
@@ -99,7 +99,7 @@ public:
    *
    * @return Initialised object
    */
-  OrderedTask(const TaskBehaviour &tb);
+  explicit OrderedTask(const TaskBehaviour &tb);
   ~OrderedTask();
 
   /**
@@ -351,11 +351,15 @@ public:
   /**
    * Accessor for task projection, for use when creating task points
    *
+   * This object is only valid if the task is not empty (see IsEmpty()).
+   *
    * @return Task global projection
    */
   gcc_pure
   const TaskProjection&
   GetTaskProjection() const {
+    assert(!IsEmpty());
+
     return task_projection;
   }
 
@@ -574,6 +578,16 @@ protected:
   void PropagateOrderedTaskSettings();
 
 public:
+  /**
+   * Check whether the task is empty.
+   *
+   * Note that even if the task is non-empty, it does not imply that
+   * the task is "valid".
+   */
+  bool IsEmpty() const noexcept {
+    return task_points.empty();
+  }
+
   ConstTaskPointList GetPoints() const {
     return task_points;
   }
@@ -629,7 +643,10 @@ public:
    * @return Location of center of task or GeoPoint::Invalid()
    */
   gcc_pure
-  GeoPoint GetTaskCenter() const;
+  GeoPoint GetTaskCenter() const noexcept {
+    assert(!IsEmpty());
+    return task_projection.GetCenter();
+  }
 
   /**
    * Find approximate radius of task from center to edge (for rendering purposes)
@@ -637,7 +654,10 @@ public:
    * @return Radius (m) from center to edge of task
    */
   gcc_pure
-  fixed GetTaskRadius() const;
+  fixed GetTaskRadius() const noexcept {
+    assert(!IsEmpty());
+    return task_projection.ApproxRadius();
+  }
 
   /**
    * returns the index of the highest intermediate TP that has been entered.
@@ -663,67 +683,68 @@ public:
 
 public:
   /* virtual methods from class TaskInterface */
-  virtual unsigned TaskSize() const override {
+  unsigned TaskSize() const override {
     return task_points.size();
   }
 
-  virtual void SetActiveTaskPoint(unsigned desired) override;
-  virtual TaskWaypoint *GetActiveTaskPoint() const override;
-  virtual bool IsValidTaskPoint(const int index_offset=0) const override;
-  virtual bool UpdateIdle(const AircraftState& state_now,
-                          const GlidePolar &glide_polar) override;
+  void SetActiveTaskPoint(unsigned desired) override;
+  TaskWaypoint *GetActiveTaskPoint() const override;
+  bool IsValidTaskPoint(const int index_offset=0) const override;
+  bool UpdateIdle(const AircraftState& state_now,
+                  const GlidePolar &glide_polar) override;
 
   /* virtual methods from class AbstractTask */
-  virtual void Reset() override;
-  virtual bool TaskStarted(bool soft=false) const override;
-  virtual bool CheckTask() const override;
+  void Reset() override;
+  bool TaskStarted(bool soft=false) const override;
+  bool CheckTask() const override;
 
 protected:
   /* virtual methods from class AbstractTask */
-  virtual bool UpdateSample(const AircraftState &state_now,
+  bool UpdateSample(const AircraftState &state_now,
+                    const GlidePolar &glide_polar,
+                    const bool full_update) override;
+  bool CheckTransitions(const AircraftState &state_now,
+                        const AircraftState &state_last) override;
+  bool CalcBestMC(const AircraftState &state_now,
+                  const GlidePolar &glide_polar,
+                  fixed& best) const override;
+  fixed CalcRequiredGlide(const AircraftState &state_now,
+                          const GlidePolar &glide_polar) const override;
+  bool CalcCruiseEfficiency(const AircraftState &state_now,
                             const GlidePolar &glide_polar,
-                            const bool full_update) override;
-  virtual bool CheckTransitions(const AircraftState &state_now,
-                                const AircraftState &state_last) override;
-  virtual bool CalcBestMC(const AircraftState &state_now,
-                          const GlidePolar &glide_polar,
-                          fixed& best) const override;
-  virtual fixed CalcRequiredGlide(const AircraftState &state_now,
-                                  const GlidePolar &glide_polar) const override;
-  virtual bool CalcCruiseEfficiency(const AircraftState &state_now,
-                                    const GlidePolar &glide_polar,
-                                    fixed &value) const override;
-  virtual bool CalcEffectiveMC(const AircraftState &state_now,
-                               const GlidePolar &glide_polar,
-                               fixed &value) const override;
-  virtual fixed CalcGradient(const AircraftState &state_now) const override;
-  virtual fixed ScanTotalStartTime() override;
-  virtual fixed ScanLegStartTime() override;
-  virtual fixed ScanDistanceNominal() override;
-  virtual fixed ScanDistancePlanned() override;
-  virtual fixed ScanDistanceRemaining(const GeoPoint &ref) override;
-  virtual fixed ScanDistanceScored(const GeoPoint &ref) override;
-  virtual fixed ScanDistanceTravelled(const GeoPoint &ref) override;
-  virtual void ScanDistanceMinMax(const GeoPoint &ref, bool full,
-                                  fixed *dmin, fixed *dmax) override;
-  virtual void GlideSolutionRemaining(const AircraftState &state_now,
-                                      const GlidePolar &polar,
-                                      GlideResult &total, GlideResult &leg) override;
-  virtual void GlideSolutionTravelled(const AircraftState &state_now,
-                                      const GlidePolar &glide_polar,
-                                      GlideResult &total, GlideResult &leg) override;
-  virtual void GlideSolutionPlanned(const AircraftState &state_now,
-                                    const GlidePolar &glide_polar,
-                                    GlideResult &total,
-                                    GlideResult &leg,
-                                    DistanceStat &total_remaining_effective,
-                                    DistanceStat &leg_remaining_effective,
-                                    const GlideResult &solution_remaining_total,
-                                    const GlideResult &solution_remaining_leg) override;
+                            fixed &value) const override;
+  bool CalcEffectiveMC(const AircraftState &state_now,
+                       const GlidePolar &glide_polar,
+                       fixed &value) const override;
+  fixed CalcGradient(const AircraftState &state_now) const override;
+  fixed ScanTotalStartTime() override;
+  fixed ScanLegStartTime() override;
+  fixed ScanDistanceNominal() override;
+  fixed ScanDistancePlanned() override;
+  fixed ScanDistanceRemaining(const GeoPoint &ref) override;
+  fixed ScanDistanceScored(const GeoPoint &ref) override;
+  fixed ScanDistanceTravelled(const GeoPoint &ref) override;
+  void ScanDistanceMinMax(const GeoPoint &ref, bool full,
+                          fixed *dmin, fixed *dmax) override;
+  void GlideSolutionRemaining(const AircraftState &state_now,
+                              const GlidePolar &polar,
+                              GlideResult &total, GlideResult &leg) override;
+  void GlideSolutionTravelled(const AircraftState &state_now,
+                              const GlidePolar &glide_polar,
+                              GlideResult &total, GlideResult &leg) override;
+  void GlideSolutionPlanned(const AircraftState &state_now,
+                            const GlidePolar &glide_polar,
+                            GlideResult &total,
+                            GlideResult &leg,
+                            DistanceStat &total_remaining_effective,
+                            DistanceStat &leg_remaining_effective,
+                            const GlideResult &solution_remaining_total,
+                            const GlideResult &solution_remaining_leg) override;
 protected:
-  virtual bool IsScored() const override;
+  bool IsScored() const override;
+
 public:
-  virtual void AcceptTaskPointVisitor(TaskPointConstVisitor &visitor) const override;
+  void AcceptTaskPointVisitor(TaskPointConstVisitor &visitor) const override;
 };
 
 #endif //ORDEREDTASK_H
