@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -60,10 +60,10 @@ public:
   }
 
   /* virtual methods from class TaskPoint */
-  virtual fixed GetElevation() const override;
+  fixed GetElevation() const override;
 
   /* virtual methods from class OrderedTaskPoint */
-  virtual void SetTaskBehaviour(const TaskBehaviour &tb) override;
+  void SetTaskBehaviour(const TaskBehaviour &tb) override;
 };
 
 #endif //INTERMEDIATEPOINT_H
