@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,18 +24,16 @@ Copyright_License {
 #ifndef XCSOAR_TRACE_VECTOR_HPP
 #define XCSOAR_TRACE_VECTOR_HPP
 
-#include "Compiler.h"
-
 #include <vector>
 
 struct GeoPoint;
+class GeoBounds;
 class TaskProjection;
 class TracePoint;
 
 class TracePointVector : public std::vector<TracePoint> {
 public:
-  gcc_pure
-  TaskProjection GetBounds(const GeoPoint &fallback_location) const;
+  void ScanBounds(GeoBounds &bounds) const;
 };
 
 /**
