@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -28,6 +28,20 @@ Copyright_License {
 
 #include <stdio.h>
 
+
+void
+FormatUserWingLoading(fixed value, TCHAR *buffer, bool include_unit)
+{
+  FormatWingLoading(buffer, value, Units::GetUserWingLoadingUnit(),
+                    include_unit);
+}
+
+void
+FormatUserMass(fixed value, TCHAR *buffer, bool include_unit)
+{
+  FormatMass(buffer, value, Units::GetUserMassUnit(), include_unit);
+}
+
 void
 FormatUserAltitude(fixed value, TCHAR *buffer, bool include_unit)
 {
