@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -28,9 +28,9 @@ Copyright_License {
 
 enum class CoordinateFormat: uint8_t {
   DDMMSS = 0,
-  DDMMSS_SS,
+  DDMMSS_S,
   DDMM_MMM,
-  DD_DDDD,
+  DD_DDDDD,
   UTM,
 };
 
