@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -49,7 +49,7 @@ SearchPointVector::ThinToSize(const unsigned max_size)
 }
 
 void 
-SearchPointVector::Project(const TaskProjection& tp)
+SearchPointVector::Project(const FlatProjection &tp)
 {
   for (auto &i : *this)
     i.Project(tp);
