@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -28,13 +28,13 @@ Copyright_License {
 #include <assert.h>
 
 TLineReader *
-OpenTextFile(const TCHAR *path, ConvertLineReader::charset cs)
+OpenTextFile(const TCHAR *path, Charset cs)
 {
-  assert(path != NULL);
+  assert(path != nullptr);
 
   FileLineReader *reader = new FileLineReader(path, cs);
-  if (reader == NULL)
-    return NULL;
+  if (reader == nullptr)
+    return nullptr;
 
   if (!reader->error())
     return reader;
@@ -42,13 +42,13 @@ OpenTextFile(const TCHAR *path, ConvertLineReader::charset cs)
   delete reader;
 
   ZipLineReader *zip_reader = new ZipLineReader(path, cs);
-  if (zip_reader == NULL)
-    return NULL;
+  if (zip_reader == nullptr)
+    return nullptr;
 
   if (!zip_reader->error())
     return zip_reader;
 
   delete zip_reader;
 
-  return NULL;
+  return nullptr;
 }
