@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,6 +24,7 @@ Copyright_License {
 #include "TextWriter.hpp"
 
 #ifdef _UNICODE
+#include "Util/StringAPI.hpp"
 #include <windows.h>
 #endif
 
@@ -48,11 +49,11 @@ TextWriter::Write(const TCHAR *s, size_t src_length)
 
   size_t dest_size = src_length * 5;
   char *dest = convert_buffer.get(dest_size);
-  if (dest == NULL)
+  if (dest == nullptr)
     return false;
 
   int length = WideCharToMultiByte(CP_UTF8, 0, s, src_length,
-                                   dest, dest_size, NULL, NULL);
+                                   dest, dest_size, nullptr, nullptr);
   if (length == 0)
     return false;
 
@@ -62,8 +63,8 @@ TextWriter::Write(const TCHAR *s, size_t src_length)
 bool
 TextWriter::Write(const TCHAR *s)
 {
-  assert(_tcschr(s, _T('\r')) == NULL);
-  assert(_tcschr(s, _T('\n')) == NULL);
+  assert(StringFind(s, _T('\r')) == nullptr);
+  assert(StringFind(s, _T('\n')) == nullptr);
 
   return Write(s, _tcslen(s));
 }
@@ -72,14 +73,14 @@ bool
 TextWriter::Format(const TCHAR *fmt, ...)
 {
   assert(IsOpen());
-  assert(fmt != NULL);
-  assert(_tcschr(fmt, _T('\r')) == NULL);
-  assert(_tcschr(fmt, _T('\n')) == NULL);
+  assert(fmt != nullptr);
+  assert(StringFind(fmt, _T('\r')) == nullptr);
+  assert(StringFind(fmt, _T('\n')) == nullptr);
 
   /* assume 4 kB is enough for one line */
   size_t buffer_size = 4096;
   TCHAR *buffer = format_buffer.get(buffer_size);
-  if (buffer == NULL)
+  if (buffer == nullptr)
     return false;
 
   va_list ap;
