@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,7 +22,6 @@ Copyright_License {
 */
 
 #include "Interface.hpp"
-#include "StatusMessage.hpp"
 #include "UIState.hpp"
 
 UIState CommonInterface::Private::ui_state;
@@ -31,5 +30,4 @@ bool CommonInterface::Private::movement_detected = false;
 
 InterfaceBlackboard CommonInterface::Private::blackboard;
 
-StatusMessageList CommonInterface::status_messages;
 MainWindow *CommonInterface::main_window;
