@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,6 +24,8 @@ Copyright_License {
 #include "LocalPath.hpp"
 #include "Compatibility/path.h"
 #include "Util/StringUtil.hpp"
+#include "Util/StringFormat.hpp"
+#include "Util/StringAPI.hpp"
 #include "Asset.hpp"
 
 #include "OS/FileUtil.hpp"
@@ -86,7 +88,7 @@ static size_t data_path_length;
 const TCHAR *
 GetPrimaryDataPath()
 {
-  assert(data_path != NULL);
+  assert(data_path != nullptr);
 
   return data_path;
 }
@@ -94,18 +96,18 @@ GetPrimaryDataPath()
 void
 SetPrimaryDataPath(const TCHAR *path)
 {
-  assert(path != NULL);
+  assert(path != nullptr);
   assert(!StringIsEmpty(path));
 
   free(data_path);
-  data_path = _tcsdup(path);
-  data_path_length = _tcslen(data_path);
+  data_path = DuplicateString(path);
+  data_path_length = StringLength(data_path);
 }
 
 void
 LocalPath(TCHAR *gcc_restrict buffer, const TCHAR *gcc_restrict file)
 {
-  assert(data_path != NULL);
+  assert(data_path != nullptr);
 
   memcpy(buffer, data_path, data_path_length * sizeof(data_path[0]));
   buffer[data_path_length] = _T(DIR_SEPARATOR);
@@ -116,10 +118,10 @@ TCHAR *
 LocalPath(TCHAR *gcc_restrict buffer, const TCHAR *gcc_restrict subdir,
           const TCHAR *gcc_restrict name)
 {
-  assert(data_path != NULL);
-  assert(subdir != NULL);
+  assert(data_path != nullptr);
+  assert(subdir != nullptr);
   assert(!StringIsEmpty(subdir));
-  assert(name != NULL);
+  assert(name != nullptr);
   assert(!StringIsEmpty(name));
 
   memcpy(buffer, data_path, data_path_length * sizeof(data_path[0]));
@@ -134,12 +136,12 @@ LocalPath(TCHAR *gcc_restrict buffer, const TCHAR *gcc_restrict subdir,
 const TCHAR *
 RelativePath(const TCHAR *path)
 {
-  assert(data_path != NULL);
+  assert(data_path != nullptr);
 
   const TCHAR *p = StringAfterPrefix(path, data_path);
-  return p != NULL && IsDirSeparator(*p)
+  return p != nullptr && IsDirSeparator(*p)
     ? p + 1
-    : NULL;
+    : nullptr;
 }
 
 /**
@@ -150,7 +152,7 @@ static void
 NormalizeBackslashes(TCHAR *p)
 {
 #if !defined(_WIN32) || defined(__WINE__)
-  while ((p = _tcschr(p, '\\')) != NULL)
+  while ((p = StringFind(p, '\\')) != nullptr)
     *p++ = '/';
 #endif
 }
@@ -162,7 +164,7 @@ ExpandLocalPath(TCHAR *dest, const TCHAR *src)
 {
   // Get the relative file name and location (ptr)
   const TCHAR *ptr = StringAfterPrefix(src, local_path_code);
-  if (ptr == NULL) {
+  if (ptr == nullptr) {
     _tcscpy(dest, src);
     return;
   }
@@ -187,11 +189,11 @@ ContractLocalPath(TCHAR* filein)
 
   // Get the relative file name and location (ptr)
   const TCHAR *relative = RelativePath(filein);
-  if (relative == NULL)
+  if (relative == nullptr)
     return;
 
   // Replace the full local path by the code "%LOCAL_PATH%\\" (output)
-  _stprintf(output, _T("%s%s"), local_path_code, relative);
+  StringFormatUnsafe(output, _T("%s%s"), local_path_code, relative);
   // ... and copy it to the buffer (filein)
   _tcscpy(filein, output);
 }
@@ -205,12 +207,12 @@ static const TCHAR *
 FindDataPathAtModule(HMODULE hModule, TCHAR *buffer)
 {
   if (GetModuleFileName(hModule, buffer, MAX_PATH) <= 0)
-    return NULL;
+    return nullptr;
 
   ReplaceBaseName(buffer, _T(XCSDATADIR));
   return Directory::Exists(buffer)
     ? buffer
-    : NULL;
+    : nullptr;
 }
 
 #endif
@@ -220,7 +222,7 @@ FindDataPathAtModule(HMODULE hModule, TCHAR *buffer)
 static bool
 InFlashNamed(const TCHAR *path, const TCHAR *name)
 {
-  size_t name_length = _tcslen(name);
+  size_t name_length = StringLength(name);
 
   return IsDirSeparator(path[0]) &&
     memcmp(path + 1, name, name_length * sizeof(name[0])) == 0 &&
@@ -234,27 +236,27 @@ InFlashNamed(const TCHAR *path, const TCHAR *name)
 static const TCHAR *
 InFlash(const TCHAR *path, TCHAR *buffer)
 {
-  assert(path != NULL);
-  assert(buffer != NULL);
+  assert(path != nullptr);
+  assert(buffer != nullptr);
 
   FlashCardEnumerator enumerator;
   const TCHAR *name;
-  while ((name = enumerator.Next()) != NULL) {
+  while ((name = enumerator.Next()) != nullptr) {
     if (InFlashNamed(path, name)) {
       buffer[0] = DIR_SEPARATOR;
-      _stprintf(buffer, _T(DIR_SEPARATOR_S"%s"), name);
+      StringFormatUnsafe(buffer, _T(DIR_SEPARATOR_S"%s"), name);
       return buffer;
     }
   }
 
-  return NULL;
+  return nullptr;
 }
 
 static const TCHAR *
 ModuleInFlash(HMODULE hModule, TCHAR *buffer)
 {
   if (GetModuleFileName(hModule, buffer, MAX_PATH) <= 0)
-    return NULL;
+    return nullptr;
 
   return InFlash(buffer, buffer);
 }
@@ -265,17 +267,18 @@ ModuleInFlash(HMODULE hModule, TCHAR *buffer)
 static const TCHAR *
 ExistingDataOnFlash(TCHAR *buffer)
 {
-  assert(buffer != NULL);
+  assert(buffer != nullptr);
 
   FlashCardEnumerator enumerator;
   const TCHAR *name;
-  while ((name = enumerator.Next()) != NULL) {
-    _stprintf(buffer, _T(DIR_SEPARATOR_S "%s" DIR_SEPARATOR_S XCSDATADIR), name);
+  while ((name = enumerator.Next()) != nullptr) {
+    StringFormatUnsafe(buffer, _T(DIR_SEPARATOR_S "%s" DIR_SEPARATOR_S XCSDATADIR),
+                       name);
     if (Directory::Exists(buffer))
       return buffer;
   }
 
-  return NULL;
+  return nullptr;
 }
 
 #elif defined(WIN32)
@@ -284,13 +287,13 @@ static const TCHAR *
 ModuleInFlash(HMODULE module, TCHAR *buffer)
 {
   if (GetModuleFileName(module, buffer, MAX_PATH) <= 0)
-    return NULL;
+    return nullptr;
 
   // At least "C:\"
-  if (_tcslen(buffer) < 3 ||
+  if (StringLength(buffer) < 3 ||
       buffer[1] != _T(':') ||
       buffer[2] != _T('\\'))
-    return NULL;
+    return nullptr;
 
   // Trim the module path to the drive letter plus colon
   buffer[2] = _T('\0');
@@ -308,16 +311,16 @@ ModuleInFlash(HMODULE module, TCHAR *buffer)
  * as no-match for the given line (i.e. string1 AND !string2).
  */
 static bool
-fgrep(const char *fname, const char *string, const char *string2 = NULL)
+fgrep(const char *fname, const char *string, const char *string2 = nullptr)
 {
   char line[100];
   FILE *fp;
 
-  if ((fp = fopen(fname, "r")) == NULL)
+  if ((fp = fopen(fname, "r")) == nullptr)
     return false;
-  while (fgets(line, sizeof(line), fp) != NULL)
-    if (strstr(line, string) != NULL &&
-        (string2 == NULL || strstr(line, string2) == NULL)) {
+  while (fgets(line, sizeof(line), fp) != nullptr)
+    if (strstr(line, string) != nullptr &&
+        (string2 == nullptr || strstr(line, string2) == nullptr)) {
         fclose(fp);
         return true;
     }
@@ -342,7 +345,7 @@ TryMountPoint(const TCHAR *mnt)
                       buffer, Directory::Exists(buffer), access(buffer, W_OK));
 
   return Directory::Exists(buffer) && access(buffer, W_OK) == 0
-    ? _tcsdup(buffer)
+    ? DuplicateString(buffer)
     : nullptr;
 }
 
@@ -359,12 +362,12 @@ GetHomeDataPath(TCHAR *gcc_restrict buffer, bool create=false)
 {
   if (IsAndroid() || IsKobo())
     /* hard-coded path for Android */
-    return NULL;
+    return nullptr;
 
 #ifdef HAVE_POSIX
   /* on Unix or WINE, use ~/.xcsoar */
   const TCHAR *home = getenv("HOME");
-  if (home != NULL) {
+  if (home != nullptr) {
     _tcscpy(buffer, home);
 #ifdef __APPLE__
     /* Mac OS X users are not used to dot-files in their home
@@ -383,16 +386,17 @@ GetHomeDataPath(TCHAR *gcc_restrict buffer, bool create=false)
        SHGetSpecialFolderPath() failure, see below */
     buffer[0] = _T('\0');
 
-  bool success = SHGetSpecialFolderPath(NULL, buffer, CSIDL_PERSONAL, create);
+  bool success = SHGetSpecialFolderPath(nullptr, buffer, CSIDL_PERSONAL,
+                                        create);
   if (IsWindowsCE() && !success && !StringIsEmpty(buffer))
     /* MSDN: "If you are using the AYGShell extensions, then this
        function returns FALSE even if successful. If the folder
        represented by the CSIDL does not exist and is not created, a
-       NULL string is returned indicating that the directory does not
+       nullptr string is returned indicating that the directory does not
        exist." */
     success = true;
   if (!success)
-    return NULL;
+    return nullptr;
 
   _tcscat(buffer, _T(DIR_SEPARATOR_S));
   _tcscat(buffer, _T(XCSDATADIR));
@@ -408,23 +412,23 @@ FindDataPath()
        internal memory is extremely small */
     const TCHAR *usb = _T("\\USB HD\\" XCSDATADIR);
     if (Directory::Exists(usb))
-      return _tcsdup(usb);
+      return DuplicateString(usb);
 
     /* hard-coded path for Altair */
-    return _tcsdup(_T("\\NOR Flash"));
+    return DuplicateString(_T("\\NOR Flash"));
   }
 
 #ifdef WIN32
   {
     TCHAR buffer[MAX_PATH];
-    const TCHAR *path = FindDataPathAtModule(NULL, buffer);
-    if (path != NULL)
-      return _tcsdup(path);
+    const TCHAR *path = FindDataPathAtModule(nullptr, buffer);
+    if (path != nullptr)
+      return DuplicateString(path);
   }
 #endif
 
   if (IsKobo())
-    return _tcsdup(_T(KOBO_USER_DATA DIR_SEPARATOR_S XCSDATADIR));
+    return DuplicateString(_T(KOBO_USER_DATA DIR_SEPARATOR_S XCSDATADIR));
 
   if (IsAndroid()) {
 #ifdef ANDROID
@@ -450,7 +454,7 @@ FindDataPath()
     /* try Context.getExternalStoragePublicDirectory() */
     char buffer[MAX_PATH];
     if (Environment::getExternalStoragePublicDirectory(buffer, sizeof(buffer),
-                                                       "XCSoarData") != NULL) {
+                                                       "XCSoarData") != nullptr) {
       __android_log_print(ANDROID_LOG_DEBUG, "XCSoar",
                           "Environment.getExternalStoragePublicDirectory()='%s'",
                           buffer);
@@ -460,7 +464,7 @@ FindDataPath()
     /* now try Context.getExternalStorageDirectory(), because
        getExternalStoragePublicDirectory() needs API level 8 */
     if (Environment::getExternalStorageDirectory(buffer,
-                                                 sizeof(buffer) - 32) != NULL) {
+                                                 sizeof(buffer) - 32) != nullptr) {
       __android_log_print(ANDROID_LOG_DEBUG, "XCSoar",
                           "Environment.getExternalStorageDirectory()='%s'",
                           buffer);
@@ -473,7 +477,7 @@ FindDataPath()
     __android_log_print(ANDROID_LOG_DEBUG, "XCSoar",
                         "Fallback " XCSDATADIR " in " ANDROID_SDCARD);
 #endif
-    return _tcsdup(_T(ANDROID_SDCARD "/" XCSDATADIR));
+    return DuplicateString(_T(ANDROID_SDCARD "/" XCSDATADIR));
   }
 
 #ifdef WIN32
@@ -481,17 +485,17 @@ FindDataPath()
      it, too */
   {
     TCHAR buffer[MAX_PATH];
-    if (ModuleInFlash(NULL, buffer) != NULL) {
+    if (ModuleInFlash(nullptr, buffer) != nullptr) {
       _tcscat(buffer, _T(DIR_SEPARATOR_S));
       _tcscat(buffer, _T(XCSDATADIR));
       if (Directory::Exists(buffer))
-        return _tcsdup(buffer);
+        return DuplicateString(buffer);
     }
 
 #ifdef _WIN32_WCE
     /* if a flash disk with XCSoarData exists, use it */
-    if (ExistingDataOnFlash(buffer) != NULL)
-      return _tcsdup(buffer);
+    if (ExistingDataOnFlash(buffer) != nullptr)
+      return DuplicateString(buffer);
 #endif
   }
 #endif
@@ -499,11 +503,11 @@ FindDataPath()
   {
     TCHAR buffer[MAX_PATH];
     const TCHAR *path = GetHomeDataPath(buffer, true);
-    if (path != NULL)
-      return _tcsdup(path);
+    if (path != nullptr)
+      return DuplicateString(path);
   }
 
-  return NULL;
+  return nullptr;
 }
 
 void
@@ -515,7 +519,7 @@ VisitDataFiles(const TCHAR* filter, File::Visitor &visitor)
   {
     TCHAR buffer[MAX_PATH];
     const TCHAR *home_path = GetHomeDataPath(buffer);
-    if (home_path != NULL && _tcscmp(data_path, home_path) != 0)
+    if (home_path != nullptr && !StringIsEqual(data_path, home_path))
       Directory::VisitSpecificFiles(home_path, filter, visitor, true);
   }
 
@@ -523,10 +527,10 @@ VisitDataFiles(const TCHAR* filter, File::Visitor &visitor)
   TCHAR flash_path[MAX_PATH];
   FlashCardEnumerator enumerator;
   const TCHAR *flash_name;
-  while ((flash_name = enumerator.Next()) != NULL) {
-    _stprintf(flash_path, _T(DIR_SEPARATOR_S "%s" DIR_SEPARATOR_S XCSDATADIR),
-              flash_name);
-    if (_tcscmp(data_path, flash_path) == 0)
+  while ((flash_name = enumerator.Next()) != nullptr) {
+    StringFormatUnsafe(flash_path, _T(DIR_SEPARATOR_S "%s" DIR_SEPARATOR_S XCSDATADIR),
+                       flash_name);
+    if (StringIsEqual(data_path, flash_path))
       /* don't scan primary data path twice */
       continue;
 
@@ -546,7 +550,7 @@ RealPath(char *path)
 {
   char buffer[4096];
   char *result = realpath(path, buffer);
-  if (result == NULL)
+  if (result == nullptr)
     return path;
 
   free(path);
@@ -558,7 +562,7 @@ bool
 InitialiseDataPath()
 {
   data_path = FindDataPath();
-  if (data_path == NULL)
+  if (data_path == nullptr)
     return false;
 
 #ifdef ANDROID
@@ -570,7 +574,7 @@ InitialiseDataPath()
   data_path = RealPath(data_path);
 #endif
 
-  data_path_length = _tcslen(data_path);
+  data_path_length = StringLength(data_path);
   return true;
 }
 
