@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -63,8 +63,9 @@ public:
 
   /**
    * @param buffer a buffer of at least #DIGEST_LENGTH+1 bytes
+   * @return a pointer to the null terminator
    */
-  void GetDigest(char *buffer) const;
+  char *GetDigest(char *buffer) const;
 };
 
 #endif
