@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,7 +24,8 @@ Copyright_License {
 #include "AllMonitors.hpp"
 #include "Interface.hpp"
 
-AllMonitors::AllMonitors() {
+AllMonitors::AllMonitors()
+  :RateLimiter(500, 25) {
   Reset();
   CommonInterface::GetLiveBlackboard().AddListener(*this);
 }
