@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -44,6 +44,7 @@ Copyright_License {
 #include "Engine/GlideSolvers/GlidePolar.hpp"
 #include "Atmosphere/Pressure.hpp"
 #include "Engine/Route/Route.hpp"
+#include "Computer/WaveResult.hpp"
 #include "Util/TypeTraits.hpp"
 
 /** Derived terrain altitude information, including glide range */
@@ -155,6 +156,8 @@ struct DerivedInfo:
 
   ClimbHistory climb_history;
 
+  WaveResult wave;
+
   /** Does #estimated_wind have a meaningful value? */
   Validity estimated_wind_available;
 
@@ -186,9 +189,14 @@ struct DerivedInfo:
     MANUAL,
 
     /**
-     * XCSoar has calculated the wind vector automatically.
+     * Calculated by #CirclingWind.
      */
-    AUTO,
+    CIRCLING,
+
+    /**
+     * Calculated by #WindEKF.
+     */
+    EKF,
 
     /**
      * The wind vector was received from an external device.
