@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -30,8 +30,8 @@ Copyright_License {
 static inline bool
 TriggerGlobalEvent(const TCHAR *name)
 {
-  HANDLE event = CreateEvent(NULL, false, false, name);
-  if (event == NULL)
+  HANDLE event = CreateEvent(nullptr, false, false, name);
+  if (event == nullptr)
     return false;
 
   bool success = SetEvent(event) != 0;
