@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@ Sleep(unsigned ms)
     static_cast<long>((ms % 1000L) * 1000000L),
   };
 
-  nanosleep(&ts, NULL);
+  nanosleep(&ts, nullptr);
 }
 
 #endif /* !WIN32 */
