@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,10 +26,13 @@ Copyright_License {
 
 #include "InfoBoxes/InfoBoxSettings.hpp"
 
+class ProfileMap;
+
 namespace Profile
 {
-  void Load(InfoBoxSettings &settings);
-  void Save(const InfoBoxSettings::Panel &panel, unsigned index);
+  void Load(const ProfileMap &map, InfoBoxSettings &settings);
+  void Save(ProfileMap &map,
+            const InfoBoxSettings::Panel &panel, unsigned index);
 };
 
 #endif
