@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,14 +24,15 @@ Copyright_License {
 #ifndef XCSOAR_PAGE_PROFILE_HPP
 #define XCSOAR_PAGE_PROFILE_HPP
 
+class ProfileMap;
 struct PageLayout;
 struct PageSettings;
 
 namespace Profile {
-  void Load(PageSettings &settings);
+  void Load(const ProfileMap &map, PageSettings &settings);
 
-  void Save(const PageLayout &page, unsigned i);
-  void Save(const PageSettings &settings);
+  void Save(ProfileMap &map, const PageLayout &page, unsigned i);
+  void Save(ProfileMap &map, const PageSettings &settings);
 };
 
 #endif
