@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -21,17 +21,18 @@ Copyright_License {
 }
 */
 
-#include "Profile/RouteProfile.hpp"
-#include "Profile/Profile.hpp"
+#include "RouteProfile.hpp"
+#include "Map.hpp"
+#include "ProfileKeys.hpp"
 #include "Engine/Route/Config.hpp"
 
 void
-Profile::Load(RoutePlannerConfig &settings)
+Profile::Load(const ProfileMap &map, RoutePlannerConfig &settings)
 {
-  Get(ProfileKeys::SafetyAltitudeTerrain, settings.safety_height_terrain);
-  GetEnum(ProfileKeys::RoutePlannerMode, settings.mode);
-  Get(ProfileKeys::RoutePlannerAllowClimb, settings.allow_climb);
-  Get(ProfileKeys::RoutePlannerUseCeiling, settings.use_ceiling);
-  GetEnum(ProfileKeys::TurningReach, settings.reach_calc_mode);
-  GetEnum(ProfileKeys::ReachPolarMode, settings.reach_polar_mode);
+  map.Get(ProfileKeys::SafetyAltitudeTerrain, settings.safety_height_terrain);
+  map.GetEnum(ProfileKeys::RoutePlannerMode, settings.mode);
+  map.Get(ProfileKeys::RoutePlannerAllowClimb, settings.allow_climb);
+  map.Get(ProfileKeys::RoutePlannerUseCeiling, settings.use_ceiling);
+  map.GetEnum(ProfileKeys::TurningReach, settings.reach_calc_mode);
+  map.GetEnum(ProfileKeys::ReachPolarMode, settings.reach_polar_mode);
 }
