@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,10 +24,11 @@ Copyright_License {
 #ifndef XCSOAR_SYSTEM_PROFILE_HPP
 #define XCSOAR_SYSTEM_PROFILE_HPP
 
+class ProfileMap;
 struct SystemSettings;
 
 namespace Profile {
-  void Load(SystemSettings &settings);
+  void Load(const ProfileMap &map, SystemSettings &settings);
 };
 
 #endif
