@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,9 +25,10 @@ Copyright_License {
 #define XCSOAR_TASK_PROFILE_HPP
 
 struct TaskBehaviour;
+class ProfileMap;
 
 namespace Profile {
-  void Load(TaskBehaviour &settings);
+  void Load(const ProfileMap &map, TaskBehaviour &settings);
 };
 
 #endif
