@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,11 +24,12 @@ Copyright_License {
 #ifndef XCSOAR_PROFILE_UNITS_CONFIG_HPP
 #define XCSOAR_PROFILE_UNITS_CONFIG_HPP
 
+class ProfileMap;
 struct UnitSetting;
 
 namespace Profile
 {
-  void LoadUnits(UnitSetting &config);
+  void LoadUnits(const ProfileMap &map, UnitSetting &config);
 };
 
 #endif
