@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@ class DemoReplayGlue
 public:
   DemoReplayGlue(ProtectedTaskManager &_task_manager);
 
-  virtual bool Update(NMEAInfo &data) override;
+  bool Update(NMEAInfo &data) override;
 };
 
 #endif
