@@ -2,7 +2,7 @@
   Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -34,13 +34,13 @@
 NmeaReplay::NmeaReplay(NLineReader *_reader, const DeviceConfig &config)
   :reader(_reader),
    parser(new NMEAParser()),
-   device(NULL)
+   device(nullptr)
 {
   parser->SetReal(false);
 
   const struct DeviceRegister *driver = FindDriverByName(config.driver_name);
-  assert(driver != NULL);
-  if (driver->CreateOnPort != NULL) {
+  assert(driver != nullptr);
+  if (driver->CreateOnPort != nullptr) {
     DeviceConfig config;
     config.Clear();
     device = driver->CreateOnPort(config, port);
@@ -61,8 +61,8 @@ NmeaReplay::ParseLine(const char *line, NMEAInfo &data)
 {
   data.clock = clock.NextClock(data.time_available ? data.time : fixed(-1));
 
-  if ((device != NULL && device->ParseNMEA(line, data)) ||
-      (parser != NULL && parser->ParseLine(line, data))) {
+  if ((device != nullptr && device->ParseNMEA(line, data)) ||
+      (parser != nullptr && parser->ParseLine(line, data))) {
     data.gps.replay = true;
     data.alive.Update(data.clock);
 
@@ -76,10 +76,12 @@ NmeaReplay::ReadUntilRMC(NMEAInfo &data)
 {
   char *buffer;
 
-  while ((buffer = reader->ReadLine()) != NULL) {
+  while ((buffer = reader->ReadLine()) != nullptr) {
     ParseLine(buffer, data);
 
-    if (StringStartsWith(buffer, "$GPRMC") ||
+    if ((StringLength(buffer) >= 6 &&
+         StringStartsWith(buffer, "$G") &&
+         StringStartsWith(buffer + 3, "RMC")) ||
         StringStartsWith(buffer, "$FLYSEN"))
       return true;
   }
