@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,7 +24,9 @@
 #include "Task/ProtectedTaskManager.hpp"
 #include "Components.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
-#include "Engine/Task/Ordered/Points/OrderedTaskPoint.hpp"
+#include "Engine/Task/Ordered/Points/StartPoint.hpp"
+#include "Engine/Task/Ordered/Points/FinishPoint.hpp"
+#include "Engine/Task/Ordered/Points/IntermediatePoint.hpp"
 #include "Engine/Task/Factory/AbstractTaskFactory.hpp"
 #include "Interface.hpp"
 
@@ -53,9 +55,8 @@ AppendToTask(OrderedTask *task, const Waypoint &waypoint)
   }
 
   const AbstractTaskFactory &factory = task->GetFactory();
-  OrderedTaskPoint *task_point =
-      (OrderedTaskPoint *)factory.CreateIntermediate(waypoint);
-  if (task_point == NULL)
+  auto *task_point = factory.CreateIntermediate(waypoint);
+  if (task_point == nullptr)
     return MapTaskManager::UNMODIFIED;
 
   bool success = i >= 0 ? task->Insert(*task_point, i) : task->Append(*task_point);
@@ -75,9 +76,8 @@ MutateFromGoto(OrderedTask *task, const Waypoint &finish_waypoint,
                const Waypoint &start_waypoint)
 {
   const AbstractTaskFactory &factory = task->GetFactory();
-  OrderedTaskPoint *start_point =
-      (OrderedTaskPoint *)factory.CreateStart(start_waypoint);
-  if (start_point == NULL)
+  auto *start_point = factory.CreateStart(start_waypoint);
+  if (start_point == nullptr)
     return MapTaskManager::UNMODIFIED;
 
   bool success = task->Append(*start_point);
@@ -85,9 +85,8 @@ MutateFromGoto(OrderedTask *task, const Waypoint &finish_waypoint,
   if (!success)
     return MapTaskManager::UNMODIFIED;
 
-  OrderedTaskPoint *finish_point =
-      (OrderedTaskPoint *)factory.CreateFinish(finish_waypoint);
-  if (finish_point == NULL)
+  auto *finish_point = factory.CreateFinish(finish_waypoint);
+  if (finish_point == nullptr)
     return MapTaskManager::UNMODIFIED;
 
   success = task->Append(*finish_point);
@@ -102,7 +101,7 @@ MutateFromGoto(OrderedTask *task, const Waypoint &finish_waypoint,
 MapTaskManager::TaskEditResult
 MapTaskManager::AppendToTask(const Waypoint &waypoint)
 {
-  assert(protected_task_manager != NULL);
+  assert(protected_task_manager != nullptr);
   ProtectedTaskManager::ExclusiveLease task_manager(*protected_task_manager);
   TaskEditResult result = MapTaskManager::UNMODIFIED;
   if (task_manager->GetOrderedTask().CheckTask()) {
@@ -159,9 +158,8 @@ InsertInTask(OrderedTask *task, const Waypoint &waypoint)
   }
 
   const AbstractTaskFactory &factory = task->GetFactory();
-  OrderedTaskPoint *task_point =
-      (OrderedTaskPoint *)factory.CreateIntermediate(waypoint);
-  if (task_point == NULL)
+  auto *task_point = factory.CreateIntermediate(waypoint);
+  if (task_point == nullptr)
     return MapTaskManager::UNMODIFIED;
 
   bool success = task->Insert(*task_point, i);
@@ -176,7 +174,7 @@ InsertInTask(OrderedTask *task, const Waypoint &waypoint)
 MapTaskManager::TaskEditResult
 MapTaskManager::InsertInTask(const Waypoint &waypoint)
 {
-  assert(protected_task_manager != NULL);
+  assert(protected_task_manager != nullptr);
   ProtectedTaskManager::ExclusiveLease task_manager(*protected_task_manager);
   TaskEditResult result = MapTaskManager::UNMODIFIED;
   if (task_manager->GetOrderedTask().CheckTask()) {
@@ -233,7 +231,7 @@ ReplaceInTask(OrderedTask *task, const Waypoint &waypoint)
 MapTaskManager::TaskEditResult
 MapTaskManager::ReplaceInTask(const Waypoint &waypoint)
 {
-  assert(protected_task_manager != NULL);
+  assert(protected_task_manager != nullptr);
   ProtectedTaskManager::ExclusiveLease task_manager(*protected_task_manager);
   OrderedTask *task = task_manager->Clone(GetTaskBehaviour());
 
@@ -270,7 +268,7 @@ GetIndexInTask(const OrderedTask &task, const Waypoint &waypoint)
 int
 MapTaskManager::GetIndexInTask(const Waypoint &waypoint)
 {
-  assert(protected_task_manager != NULL);
+  assert(protected_task_manager != nullptr);
   ProtectedTaskManager::ExclusiveLease task_manager(*protected_task_manager);
   if (task_manager->GetMode() == TaskType::ORDERED) {
     const OrderedTask &task = task_manager->GetOrderedTask();
@@ -305,7 +303,7 @@ RemoveFromTask(OrderedTask *task, const Waypoint &waypoint)
 MapTaskManager::TaskEditResult
 MapTaskManager::RemoveFromTask(const Waypoint &wp)
 {
-  assert(protected_task_manager != NULL);
+  assert(protected_task_manager != nullptr);
   ProtectedTaskManager::ExclusiveLease task_manager(*protected_task_manager);
   OrderedTask *task = task_manager->Clone(GetTaskBehaviour());
 
