@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,14 +26,14 @@ Copyright_License {
 
 #include "TerrainRenderer.hpp"
 
-class RasterWeather;
+class RasterWeatherCache;
 
 class WeatherTerrainRenderer: public TerrainRenderer {
-  const RasterWeather *weather;
+  const RasterWeatherCache &weather;
 
 public:
-  WeatherTerrainRenderer(const RasterTerrain *_terrain,
-                         const RasterWeather *_weather);
+  WeatherTerrainRenderer(const RasterTerrain &_terrain,
+                         const RasterWeatherCache &_weather);
 
   virtual void Generate(const WindowProjection &map_projection,
                         const Angle sunazimuth);
