@@ -9,9 +9,9 @@
  * 
  * JasPer License Version 2.0
  * 
+ * Copyright (c) 2001-2006 Michael David Adams
  * Copyright (c) 1999-2000 Image Power, Inc.
  * Copyright (c) 1999-2000 The University of British Columbia
- * Copyright (c) 2001-2003 Michael David Adams
  * 
  * All rights reserved.
  * 
@@ -78,6 +78,7 @@
 #include "jasper/jas_fix.h"
 #include "jasper/jas_stream.h"
 #include "jasper/jas_math.h"
+#include "jasper/jas_debug.h"
 
 #include "jpc_bs.h"
 #include "jpc_mqdec.h"
@@ -102,25 +103,37 @@ static int dec_rawrefpass(jpc_dec_t *dec, jpc_bitstream_t *in, int bitpos,
 static int dec_clnpass(jpc_dec_t *dec, jpc_mqdec_t *mqdec, int bitpos, int orient,
   int vcausalflag, int segsymflag, jas_matrix_t *flags, jas_matrix_t *data);
 
-#ifdef NDEBUG
+#if defined(DEBUG)
+static long t1dec_cnt = 0;
+#endif
+
+#if !defined(DEBUG)
 #define	JPC_T1D_GETBIT(mqdec, v, passtypename, symtypename) \
 	((v) = jpc_mqdec_getbit(mqdec))
 #else
 #define	JPC_T1D_GETBIT(mqdec, v, passtypename, symtypename) \
 { \
 	(v) = jpc_mqdec_getbit(mqdec); \
+	if (jas_getdbglevel() >= 100) { \
+		jas_eprintf("index = %ld; passtype = %s; symtype = %s; sym = %d\n", t1dec_cnt, passtypename, symtypename, v); \
+		++t1dec_cnt; \
+	} \
 }
 #endif
 #define	JPC_T1D_GETBITNOSKEW(mqdec, v, passtypename, symtypename) \
 	JPC_T1D_GETBIT(mqdec, v, passtypename, symtypename)
 
-#ifdef NDEBUG
+#if !defined(DEBUG)
 #define	JPC_T1D_RAWGETBIT(bitstream, v, passtypename, symtypename) \
 	((v) = jpc_bitstream_getbit(bitstream))
 #else
 #define	JPC_T1D_RAWGETBIT(bitstream, v, passtypename, symtypename) \
 { \
 	(v) = jpc_bitstream_getbit(bitstream); \
+	if (jas_getdbglevel() >= 100) { \
+		jas_eprintf("index = %ld; passtype = %s; symtype = %s; sym = %d\n", t1dec_cnt, passtypename, symtypename, v); \
+		++t1dec_cnt; \
+	} \
 }
 #endif
 
@@ -140,19 +153,10 @@ int jpc_dec_decodecblks(jpc_dec_t *dec, jpc_dec_tile_t *tile)
 	int prccnt;
 	jpc_dec_cblk_t *cblk;
 	int cblkcnt;
-	int ilevel;
 
 	for (compcnt = dec->numcomps, tcomp = tile->tcomps; compcnt > 0;
 	  --compcnt, ++tcomp) {
-
-		ilevel = tcomp->numrlvls;
-		// JMW
-		if (dec->xcsoar == 2) {
-			// JMW don't do this, too many errors
-			//ilevel = min(ilevel,1);
-		}
-
-		for (rlvlcnt = ilevel, rlvl = tcomp->rlvls;
+		for (rlvlcnt = tcomp->numrlvls, rlvl = tcomp->rlvls;
 		  rlvlcnt > 0; --rlvlcnt, ++rlvl) {
 			if (!rlvl->bands) {
 				continue;
@@ -237,14 +241,10 @@ static int jpc_dec_decodecblk(jpc_dec_t *dec, jpc_dec_tile_t *tile, jpc_dec_tcom
 			if (cblk->numimsbs > band->numbps) {
 				ccp = &tile->cp->ccps[compno];
 				if (ccp->roishift <= 0) {
-#if 0 // JMW
-					fprintf(stderr, "warning: corrupt code stream\n");
-#endif
+					jas_eprintf("warning: corrupt code stream\n");
 				} else {
 					if (cblk->numimsbs < ccp->roishift - band->numbps) {
-#if 0 // JMW
-						fprintf(stderr, "warning: corrupt code stream\n");
-#endif
+						jas_eprintf("warning: corrupt code stream\n");
 					}
 				}
 			}
@@ -296,9 +296,7 @@ if (bpno < 0) {
 			}
 
 			if (ret) {
-#if 0 // JMW
-				fprintf(stderr, "coding pass failed passtype=%d segtype=%d\n", passtype, seg->type);
-#endif
+				jas_eprintf("coding pass failed passtype=%d segtype=%d\n", passtype, seg->type);
 				return -1;
 			}
 
@@ -319,9 +317,7 @@ if (bpno < 0) {
 			  filldata)) < 0) {
 				return -1;
 			} else if (ret > 0) {
-#if 0 // JMW
-				fprintf(stderr, "warning: bad termination pattern detected\n");
-#endif
+				jas_eprintf("warning: bad termination pattern detected\n");
 			}
 			jpc_bitstream_close(cblk->nulldec);
 			cblk->nulldec = 0;
@@ -374,12 +370,12 @@ static int dec_sigpass(jpc_dec_t *dec, register jpc_mqdec_t *mqdec, int bitpos,
 	int vscanlen;
 	int width;
 	int height;
-	jpc_fix_t *fp;
+	jpc_fix_t *restrict fp;
 	int frowstep;
 	int fstripestep;
 	jpc_fix_t *fstripestart;
 	jpc_fix_t *fvscanstart;
-	jpc_fix_t *dp;
+	jpc_fix_t *restrict dp;
 	int drowstep;
 	int dstripestep;
 	jpc_fix_t *dstripestart;
@@ -481,12 +477,12 @@ static int dec_rawsigpass(jpc_dec_t *dec, jpc_bitstream_t *in, int bitpos, int v
 	int vscanlen;
 	int width;
 	int height;
-	jpc_fix_t *fp;
+	jpc_fix_t *restrict fp;
 	int frowstep;
 	int fstripestep;
 	jpc_fix_t *fstripestart;
 	jpc_fix_t *fvscanstart;
-	jpc_fix_t *dp;
+	jpc_fix_t *restrict dp;
 	int drowstep;
 	int dstripestep;
 	jpc_fix_t *dstripestart;
@@ -582,12 +578,12 @@ static int dec_refpass(jpc_dec_t *dec, register jpc_mqdec_t *mqdec, int bitpos,
 	int one;
 	int poshalf;
 	int neghalf;
-	jpc_fix_t *fp;
+	jpc_fix_t *restrict fp;
 	int frowstep;
 	int fstripestep;
 	jpc_fix_t *fstripestart;
 	jpc_fix_t *fvscanstart;
-	jpc_fix_t *dp;
+	jpc_fix_t *restrict dp;
 	int drowstep;
 	int dstripestep;
 	jpc_fix_t *dstripestart;
@@ -681,12 +677,12 @@ static int dec_rawrefpass(jpc_dec_t *dec, jpc_bitstream_t *in, int bitpos, int v
 	int one;
 	int poshalf;
 	int neghalf;
-	jpc_fix_t *fp;
+	jpc_fix_t *restrict fp;
 	int frowstep;
 	int fstripestep;
 	jpc_fix_t *fstripestart;
 	jpc_fix_t *fvscanstart;
-	jpc_fix_t *dp;
+	jpc_fix_t *restrict dp;
 	int drowstep;
 	int dstripestep;
 	jpc_fix_t *dstripestart;
@@ -793,13 +789,13 @@ static int dec_clnpass(jpc_dec_t *dec, register jpc_mqdec_t *mqdec, int bitpos,
 	int one;
 	int oneplushalf;
 
-	jpc_fix_t *fp;
+	jpc_fix_t *restrict fp;
 	int frowstep;
 	int fstripestep;
 	jpc_fix_t *fstripestart;
 	jpc_fix_t *fvscanstart;
 
-	jpc_fix_t *dp;
+	jpc_fix_t *restrict dp;
 	int drowstep;
 	int dstripestep;
 	jpc_fix_t *dstripestart;
@@ -919,9 +915,7 @@ static int dec_clnpass(jpc_dec_t *dec, register jpc_mqdec_t *mqdec, int bitpos,
 		JPC_T1D_GETBITNOSKEW(mqdec, v, "CLN", "SEGSYM");
 		segsymval = (segsymval << 1) | (v & 1);
 		if (segsymval != 0xa) {
-#if 0 // JMW
-			fprintf(stderr, "warning: bad segmentation symbol\n");
-#endif
+			jas_eprintf("warning: bad segmentation symbol\n");
 		}
 	}
 
