@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -70,7 +70,7 @@ public:
   /**
    * Initializes the Mutex
    */
-#if defined(HAVE_POSIX) && defined(NDEBUG) && (!defined(__BIONIC__) || !defined(__clang__))
+#if defined(NDEBUG) && defined(__GLIBC__) && !defined(__gnu_hurd__)
   constexpr
 #endif
   Mutex()
