@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@ Copyright_License {
 #include "Util.hpp"
 
 #ifdef ANDROID
-#include "Java/Global.hpp"
+#include "Java/Global.hxx"
 #endif
 
 #include <assert.h>
@@ -66,7 +66,17 @@ Thread::Start()
   creating = true;
 #endif
 
+#if defined(__GLIBC__) || defined(__BIONIC__) || defined(__APPLE__)
   defined = pthread_create(&handle, nullptr, ThreadProc, this) == 0;
+#else
+  /* In other libc implementations, the default stack size for created threads
+     might not be large enough (e. g. 80 KB on musl libc).
+     640 KB ought to be enough for anybody. */
+  pthread_attr_t attr;
+  defined = (pthread_attr_init(&attr) == 0) &&
+            (pthread_attr_setstacksize(&attr, 640 * 1024) == 0) &&
+            (pthread_create(&handle, &attr, ThreadProc, this) == 0);
+#endif
 
 #ifndef NDEBUG
   creating = false;
