@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -102,7 +102,7 @@ namespace LiveTrack24
   /** Sends the "start of track" packet to the tracking server */
   bool StartTracking(SessionID session, const TCHAR *username,
                      const TCHAR *password, unsigned tracking_interval,
-                     VehicleType vtype, const char *vname = nullptr);
+                     VehicleType vtype, const TCHAR *vname);
 
   /**
    * Sends a "gps point" packet to the tracking server
