@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -37,6 +37,22 @@ gcc_pure  gcc_nonnull_all
 bool
 ValidateUTF8(const char *p);
 
+/**
+ * @return the number of the sequence beginning with the given
+ * character, or 0 if the character is not a valid start byte
+ */
+gcc_const
+size_t
+SequenceLengthUTF8(char ch);
+
+/**
+ * @return the number of the first sequence in the given string, or 0
+ * if the sequence is malformed
+ */
+gcc_pure
+size_t
+SequenceLengthUTF8(const char *p);
+
 /**
  * Convert the specified string from ISO-8859-1 to UTF-8.
  *
@@ -85,11 +101,38 @@ LengthUTF8(const char *p);
  * incomplete sequence.
  *
  * The rest of the string must be valid UTF-8.
+ *
+ * @return a pointer to the new null terminator
  */
 gcc_nonnull_all
-void
+char *
 CropIncompleteUTF8(char *p);
 
+/**
+ * Return the number of bytes representing the first #max_chars
+ * characters of a null-terminated string.  If the string has fewer
+ * characters, the string length (in bytes) is returned.  No partial
+ * multi-byte sequence will be considered.
+ */
+gcc_pure gcc_nonnull_all
+size_t
+TruncateStringUTF8(const char *p, size_t max_chars, size_t max_bytes);
+
+/**
+ * Copy a string to a buffer, truncating it if the buffer is not large
+ * enough.  At most #truncate characters will be copied.  No partial
+ * multi-byte sequence will be copied.
+ *
+ * @param dest_size the total size of the destination buffer, which
+ * includes the null byte
+ * @param truncate the maximum number of characters (not bytes) to
+ * copy
+ * @return a pointer to the end of the destination string
+ */
+char *
+CopyTruncateStringUTF8(char *dest, size_t dest_size,
+                       const char *src, size_t truncate);
+
 /**
  * Decode the next UNICODE character.
  *
