@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,17 +26,14 @@ Copyright_License {
 
 #include "WaypointReaderBase.hpp"
 
-class WaypointReaderZander: 
-  public WaypointReaderBase 
-{
+class WaypointReaderZander final : public WaypointReaderBase {
 public:
-  WaypointReaderZander(const int _file_num,
-                     bool _compressed = false)
-    :WaypointReaderBase(_file_num, _compressed) {}
+  explicit WaypointReaderZander(WaypointFactory _factory)
+    :WaypointReaderBase(_factory) {}
 
 protected:
-  bool ParseLine(const TCHAR* line, const unsigned linenum,
-                 Waypoints &way_points);
+  /* virtual methods from class WaypointReaderBase */
+  bool ParseLine(const TCHAR *line, Waypoints &way_points) override;
 };
 
 #endif
