@@ -29,6 +29,7 @@
 #include "Parser.hpp"
 #include "Node.hpp"
 #include "Util/CharUtil.hpp"
+#include "Util/StringAPI.hpp"
 #include "Util/StringUtil.hpp"
 #include "Util/NumberParser.hpp"
 #include "IO/FileLineReader.hpp"
@@ -351,6 +352,10 @@ XML::GetNextToken(Parser *pXML)
     // If we haven't found a short hand closing tag then drop into the
     // text process
 
+#if GCC_CHECK_VERSION(7,0)
+    [[fallthrough]];
+#endif
+
     // Other characters
   default:
     is_text = true;
@@ -439,24 +444,6 @@ XML::GetErrorMessage(Error error)
   return _T("Unknown");
 }
 
-/**
- * Trim the end of the text to remove white space characters.
- */
-gcc_pure
-static size_t
-FindEndOfText(const TCHAR *token, size_t length)
-{
-  assert(token != nullptr);
-
-  --length;
-  while (1) {
-    if (IsWhitespaceOrNull(token[length]))
-      return length + 1;
-
-    --length;
-  }
-}
-
 /**
  * Recursively parse an XML element.
  */
@@ -515,7 +502,7 @@ XML::ParseXMLElement(XMLNode &node, Parser *pXML)
 
         // If we have node text then add this to the element
         if (text != nullptr) {
-          size_t length = FindEndOfText(text, token.pStr - text);
+          size_t length = StripRight(text, token.pStr - text);
           node.AddText(text, length);
           text = nullptr;
         }
@@ -580,7 +567,7 @@ XML::ParseXMLElement(XMLNode &node, Parser *pXML)
 
         // If we have node text then add this to the element
         if (text != nullptr) {
-          size_t length = FindEndOfText(text, token.pStr - text);
+          size_t length = StripRight(text, token.pStr - text);
           TCHAR *text2 = FromXMLString(text, length);
           if (text2 == nullptr) {
             pXML->error = eXMLErrorUnexpectedToken;
@@ -758,6 +745,11 @@ XML::ParseXMLElement(XMLNode &node, Parser *pXML)
 
           {
             TCHAR *value = FromXMLString(token.pStr, token.length);
+            if (value == nullptr) {
+              pXML->error = eXMLErrorUnexpectedToken;
+              return false;
+            }
+
             node.AddAttribute(std::move(attribute_name),
                               value, _tcslen(value));
             free(value);
@@ -907,7 +899,7 @@ ReadTextFile(const TCHAR *path, tstring &buffer)
 {
   /* auto-detect the character encoding, to be able to parse XCSoar
      6.0 task files */
-  FileLineReader reader(path, ConvertLineReader::AUTO);
+  FileLineReader reader(path, Charset::AUTO);
   if (reader.error())
     return false;
 
