@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@ enum {
   DT_NOCLIP = 0x4,
   DT_WORDBREAK = 0x8,
   DT_CENTER = 0x20,
-  DT_NOPREFIX = 0x40,
+  DT_NOPREFIX = 0,
   DT_VCENTER = 0x80,
   DT_RIGHT = 0x100,
   DT_CALCRECT = 0x400,
