@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -32,6 +32,11 @@ Copyright_License {
 #include <stdio.h>
 #include <stdlib.h>
 
+#ifdef __clang__
+/* true, the nullptr cast below is a bad kludge */
+#pragma GCC diagnostic ignored "-Wnull-dereference"
+#endif
+
 int main(int argc, char **argv)
 {
   Args args(argc, argv, "PORT BAUD");
@@ -40,7 +45,7 @@ int main(int argc, char **argv)
 
   InitialiseIOThread();
 
-  Port *port = OpenPort(config, *(DataHandler *)NULL);
+  Port *port = OpenPort(config, nullptr, *(DataHandler *)nullptr);
   if (port == NULL) {
     delete port;
     fprintf(stderr, "Failed to open COM port\n");
