@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -342,7 +342,7 @@ main(int argc, char **argv)
   InitialiseIOThread();
 
   NullDataHandler handler;
-  std::unique_ptr<Port> port(OpenPort(config, handler));
+  std::unique_ptr<Port> port(OpenPort(config, nullptr, handler));
   if (!port) {
     fprintf(stderr, "Failed to open COM port\n");
     return EXIT_FAILURE;
