@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -34,7 +34,6 @@
 #include "Device/Driver/FlymasterF1.hpp"
 #include "Device/Driver/FlyNet.hpp"
 #include "Device/Driver/Flytec.hpp"
-#include "Device/Driver/GTAltimeter.hpp"
 #include "Device/Driver/LevilAHRS_G.hpp"
 #include "Device/Driver/Leonardo.hpp"
 #include "Device/Driver/LX.hpp"
@@ -43,6 +42,7 @@
 #include "Device/Driver/IMI.hpp"
 #include "Device/Driver/OpenVario.hpp"
 #include "Device/Driver/PosiGraph.hpp"
+#include "Device/Driver/Vaulter.hpp"
 #include "Device/Driver/Vega.hpp"
 #include "Device/Driver/Volkslogger.hpp"
 #include "Device/Driver/Westerboer.hpp"
@@ -106,11 +106,24 @@ TestGeneric()
   ok1(equals(nmea_info.location.longitude, 7.693));
   ok1(equals(nmea_info.location.latitude, 51.059));
   ok1(!nmea_info.baro_altitude_available);
+  ok1(nmea_info.variation_available);
+  ok1(equals(nmea_info.variation, -000.3));
 
   /* baro altitude (proprietary Garmin sentence) */
   ok1(parser.ParseLine("$PGRMZ,100,m,3*11", nmea_info));
   ok1(nmea_info.baro_altitude_available);
   ok1(equals(nmea_info.baro_altitude, 100));
+
+  /* Magnetic Heading ok */
+  ok1(parser.ParseLine("$HCHDM,182.7,M*25", nmea_info));
+  ok1(nmea_info.heading_available);
+  ok1(equals(nmea_info.heading, 182.7));
+
+  /* Magnetic Heading bad char */
+  ok1(!parser.ParseLine("$HCHDM,1x2.7,M*25", nmea_info));
+
+  /* Magnetic Heading bad checksum */
+  ok1(!parser.ParseLine("$HCHDM,182.7,M*26", nmea_info));
 }
 
 static void
@@ -263,44 +276,6 @@ TestAltairRU()
   ok1(equals(nmea_info.voltage, 12.743));
 }
 
-static void
-TestGTAltimeter()
-{
-  NullPort null;
-  Device *device = gt_altimeter_driver.CreateOnPort(dummy_config, null);
-  ok1(device != NULL);
-
-  NMEAInfo nmea_info;
-  nmea_info.Reset();
-  nmea_info.clock = fixed(1);
-
-  ok1(device->ParseNMEA("$LK8EX1,99545,149,1,26,5.10*18", nmea_info));
-  ok1(nmea_info.static_pressure_available);
-  ok1(equals(nmea_info.static_pressure.GetHectoPascal(), 995.45));
-  ok1(!nmea_info.pressure_altitude_available);
-  ok1(nmea_info.noncomp_vario_available);
-  ok1(equals(nmea_info.noncomp_vario, 0.01));
-  ok1(nmea_info.temperature_available);
-  ok1(equals(nmea_info.temperature, 26));
-  ok1(!nmea_info.battery_level_available);
-  ok1(nmea_info.voltage_available);
-  ok1(equals(nmea_info.voltage, 5.1));
-
-  nmea_info.Reset();
-  nmea_info.clock = fixed(1);
-
-  ok1(device->ParseNMEA("$LK8EX1,999999,149,-123,,1076,*32", nmea_info));
-  ok1(!nmea_info.static_pressure_available);
-  ok1(nmea_info.pressure_altitude_available);
-  ok1(equals(nmea_info.pressure_altitude, 149));
-  ok1(nmea_info.noncomp_vario_available);
-  ok1(equals(nmea_info.noncomp_vario, -1.23));
-  ok1(!nmea_info.temperature_available);
-  ok1(nmea_info.battery_level_available);
-  ok1(equals(nmea_info.battery_level, 76));
-  ok1(!nmea_info.voltage_available);
-}
-
 static void
 TestBlueFly()
 {
@@ -1366,10 +1341,56 @@ TestZander()
   delete device;
 }
 
+static void
+TestVaulter()
+{
+  NullPort null;
+  Device *device = vaulter_driver.CreateOnPort(dummy_config, null);
+  ok1(device != NULL);
+
+  NMEAInfo nmea_info;
+  nmea_info.Reset();
+  nmea_info.clock = fixed(1);
+
+  ok1(device->ParseNMEA("$PITV3,-16.0,-23.9,147.9,23.03,1.01*1C", nmea_info));
+  ok1(nmea_info.attitude.bank_angle_available);
+  ok1(equals(nmea_info.attitude.bank_angle, -16.0));
+  ok1(nmea_info.attitude.pitch_angle_available);
+  ok1(equals(nmea_info.attitude.pitch_angle, -23.9));
+  ok1(nmea_info.attitude.heading_available);
+  ok1(equals(nmea_info.attitude.heading, 147.9));
+
+  ok1(nmea_info.airspeed_available);
+  ok1(equals(nmea_info.indicated_airspeed, 23.03));
+
+  ok1(nmea_info.acceleration.available);
+  ok1(nmea_info.acceleration.real);
+  ok1(equals(nmea_info.acceleration.g_load, 1.01));
+
+  ok1(device->ParseNMEA("$PITV4,-0.04,0.57,-0.44,-102.0,-74.8,-73.7*3F", nmea_info));
+  ok1(nmea_info.total_energy_vario_available);
+  ok1(equals(nmea_info.total_energy_vario, -0.04));
+
+  ok1(device->ParseNMEA("$PITV5,6.8,29.2,0.995,0.03,0,1.54*01", nmea_info));
+  ok1(nmea_info.external_wind_available);
+  ok1(equals(nmea_info.external_wind.bearing, 29.2));
+  ok1(equals(nmea_info.external_wind.norm, 6.8));
+
+  ok1(nmea_info.switch_state.flight_mode == SwitchState::FlightMode::CIRCLING);
+  ok1(equals(nmea_info.settings.mac_cready, 1.54));
+
+  delete device;
+}
+
+#ifdef __clang__
+/* true, the nullptr cast below is a bad kludge */
+#pragma GCC diagnostic ignored "-Wnull-dereference"
+#endif
+
 static void
 TestDeclare(const struct DeviceRegister &driver)
 {
-  FaultInjectionPort port(*(DataHandler *)NULL);
+  FaultInjectionPort port(nullptr, *(DataHandler *)nullptr);
   Device *device = driver.CreateOnPort(dummy_config, port);
   ok1(device != NULL);
 
@@ -1411,7 +1432,7 @@ TestDeclare(const struct DeviceRegister &driver)
 static void
 TestFlightList(const struct DeviceRegister &driver)
 {
-  FaultInjectionPort port(*(DataHandler *)NULL);
+  FaultInjectionPort port(nullptr, *(DataHandler *)nullptr);
   Device *device = driver.CreateOnPort(dummy_config, port);
   ok1(device != NULL);
 
@@ -1435,13 +1456,12 @@ TestFlightList(const struct DeviceRegister &driver)
 
 int main(int argc, char **argv)
 {
-  plan_tests(754);
+  plan_tests(761);
 
   TestGeneric();
   TestTasman();
   TestFLARM();
   TestAltairRU();
-  TestGTAltimeter();
   TestBlueFly();
   TestBorgeltB50();
   TestCAI302();
@@ -1460,6 +1480,7 @@ int main(int argc, char **argv)
   TestWesterboer();
   TestZander();
   TestFlyNet();
+  TestVaulter();
 
   /* XXX the Triadis drivers have too many dependencies, not enabling
      for now */
