@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -34,7 +34,7 @@ MakeGeoBounds(int west, int north, int east, int south)
 
 int main(int argc, char **argv)
 {
-  plan_tests(38);
+  plan_tests(58);
 
   GeoPoint g(Angle::Degrees(2), Angle::Degrees(4));
 
@@ -82,12 +82,18 @@ int main(int argc, char **argv)
   ok1(equals(b.GetSouth(), 4));
 
   GeoBounds c = MakeGeoBounds(2, 6, 8, 4);
+  const GeoBounds c2 = c;
   ok1(c.Overlaps(b));
   ok1(c.IntersectWith(b));
   ok1(equals(c.GetWest(), 2));
   ok1(equals(c.GetNorth(), 6));
   ok1(equals(c.GetEast(), 8));
   ok1(equals(c.GetSouth(), 4));
+  ok1(b.IntersectWith(c2));
+  ok1(equals(b.GetWest(), 2));
+  ok1(equals(b.GetNorth(), 6));
+  ok1(equals(b.GetEast(), 8));
+  ok1(equals(b.GetSouth(), 4));
 
   GeoBounds d = MakeGeoBounds(2, 6, 7, 5);
   ok1(c.Overlaps(d));
@@ -96,10 +102,32 @@ int main(int argc, char **argv)
   ok1(equals(c.GetNorth(), 6));
   ok1(equals(c.GetEast(), 7));
   ok1(equals(c.GetSouth(), 5));
+  ok1(d.IntersectWith(c2));
+  ok1(equals(d.GetWest(), 2));
+  ok1(equals(d.GetNorth(), 6));
+  ok1(equals(d.GetEast(), 7));
+  ok1(equals(d.GetSouth(), 5));
 
   d = MakeGeoBounds(8, 6, 1, 5);
   ok1(!c.Overlaps(d));
   ok1(!c.IntersectWith(d));
 
+  const GeoBounds outer = MakeGeoBounds(10, 20, 20, 10);
+  const GeoBounds inner = MakeGeoBounds(12, 18, 18, 12);
+
+  GeoBounds x = outer;
+  ok1(x.IntersectWith(inner));
+  ok1(equals(x.GetWest(), inner.GetWest()));
+  ok1(equals(x.GetNorth(), inner.GetNorth()));
+  ok1(equals(x.GetEast(), inner.GetEast()));
+  ok1(equals(x.GetSouth(), inner.GetSouth()));
+
+  x = inner;
+  ok1(x.IntersectWith(outer));
+  ok1(equals(x.GetWest(), inner.GetWest()));
+  ok1(equals(x.GetNorth(), inner.GetNorth()));
+  ok1(equals(x.GetEast(), inner.GetEast()));
+  ok1(equals(x.GetSouth(), inner.GetSouth()));
+
   return exit_status();
 }
