@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2014 The XCSoar Project
+  Copyright (C) 2000-2015 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,6 +25,10 @@
 #include "test_debug.hpp"
 #include "Engine/Waypoint/Waypoints.hpp"
 
+extern "C" {
+#include "tap.h"
+}
+
 int main(int argc, char** argv)
 {
   if (!ParseArgs(argc,argv)) {
